module.exports = {
  mixins: [require("vue-mixins/onceDocument"), require("vue-mixins/isOpened")],
  filters: {
    notPrevented: require("vue-filters/notPrevented")
  },
  props: {
    "class": {
      "default": function() {
        return ["fixed-action-btn"];
      }
    },
    "closeOnClick": {
      type: Boolean,
      defaul: false
    },
    "clickToToggle": {
      type: Boolean,
      "default": false
    },
    "notDismissable": {
      type: Boolean,
      "default": false
    },
    "transitionIn": {
      type: Function,
      "default": function(arg) {
        var cb, el;
        el = arg.el, cb = arg.cb;
        return cb();
      }
    },
    "transitionOut": {
      type: Function,
      "default": function(arg) {
        var cb, el;
        el = arg.el, cb = arg.cb;
        return cb();
      }
    }
  },
  data: function() {
    return {
      removeDocumentClickListener: null,
      clickInside: false,
      clickFab: false
    };
  },
  methods: {
    onHover: function() {
      if (!this.clickToToggle) {
        return this.open();
      }
    },
    onUnhover: function() {
      if (!this.clickToToggle) {
        return this.close();
      }
    },
    onFabClick: function(e) {
      if (this.clickToToggle) {
        e.preventDefault();
        this.toggle();
        this.clickFab = true;
        return setTimeout(((function(_this) {
          return function() {
            return _this.clickFab = false;
          };
        })(this)), 10);
      }
    },
    onInnerClick: function() {
      this.setClickInside();
      if (this.closeOnClick && !this.clickFab) {
        return this.close();
      }
    },
    setClickInside: function() {
      this.clickInside = true;
      return setTimeout(((function(_this) {
        return function() {
          return _this.clickInside = false;
        };
      })(this)), 10);
    },
    show: function() {
      if (this.opened) {
        return;
      }
      this.setOpened();
      return this.$nextTick((function(_this) {
        return function() {
          if (!_this.notDismissable && _this.clickToToggle) {
            if (typeof _this.removeDocumentClickListener === "function") {
              _this.removeDocumentClickListener();
            }
            _this.removeDocumentClickListener = _this.onceDocument("click", function(e) {
              if (!_this.clickInside) {
                _this.hide();
              }
              return !_this.clickInside;
            });
            if (typeof _this.removeDocumentKeyupListener === "function") {
              _this.removeDocumentKeyupListener();
            }
            _this.removeDocumentKeyupListener = _this.onceDocument("keyup", function(e) {
              if (!e.defaultPrevented) {
                if (e.which === 27) {
                  e.preventDefault();
                  _this.hide();
                  return true;
                }
              }
              return false;
            });
          }
          _this.$emit("before-open");
          return _this.transitionIn({
            el: _this.$els.fab,
            cb: function() {
              return _this.$emit("opened");
            }
          });
        };
      })(this));
    },
    hide: function() {
      if (!this.opened) {
        return;
      }
      if (typeof this.removeDocumentClickListener === "function") {
        this.removeDocumentClickListener();
      }
      this.removeDocumentClickListener = null;
      if (typeof this.removeDocumentKeyupListener === "function") {
        this.removeDocumentKeyupListener();
      }
      this.removeDocumentKeyupListener = null;
      this.$emit("before-close");
      return this.transitionOut({
        el: this.$els.fab,
        cb: (function(_this) {
          return function() {
            _this.setClosed();
            return _this.$emit("closed");
          };
        })(this)
      });
    },
    open: function() {
      return this.show();
    },
    close: function() {
      return this.hide();
    },
    toggle: function() {
      if (this.opened) {
        return this.close();
      } else {
        return this.open();
      }
    }
  },
  dettached: function() {
    if (typeof this.removeDocumentClickListener === "function") {
      this.removeDocumentClickListener();
    }
    return typeof this.removeDocumentKeyupListener === "function" ? this.removeDocumentKeyupListener() : void 0;
  },
  events: {
    close: function() {
      this.close();
      return true;
    }
  }
};

if (module.exports.__esModule) module.exports = module.exports.default
;(typeof module.exports === "function"? module.exports.options: module.exports).template = "<div :style=\"{position:'fixed'}\" @click.prevent=onInnerClick @mouseenter=onHover @mouseleave=onUnhover :class=class><ul v-if=opened v-el:fab=v-el:fab><slot>No content</slot></ul><span @click=\"onFabClick | notPrevented\"><slot name=fab></slot></span></div>"
